aboutsummaryrefslogtreecommitdiffstats
path: root/pkg/datamaps/reader.go
diff options
context:
space:
mode:
authorMatthew Lemon <matt@matthewlemon.com>2020-07-26 19:50:49 +0100
committerMatthew Lemon <matt@matthewlemon.com>2020-07-26 19:50:49 +0100
commit3d9fcd0c1d56a5f5534163d56c9d65321ded4bc5 (patch)
tree7363d1f130d08639b001948f8ba7de128a620e6c /pkg/datamaps/reader.go
parent474763178383049f882139d7cc352477906727c9 (diff)
renamed func
Diffstat (limited to 'pkg/datamaps/reader.go')
-rw-r--r--pkg/datamaps/reader.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkg/datamaps/reader.go b/pkg/datamaps/reader.go
index bb4cad7..892e4d8 100644
--- a/pkg/datamaps/reader.go
+++ b/pkg/datamaps/reader.go
@@ -147,9 +147,9 @@ func ReadXLSX(ssheet string) FileData {
return outer
}
// DMLFromDB fetches a slice of DatamapLine from the database given
// the name of a datamap.
-func DMLFromDB(name string, db *sql.DB) ([]DatamapLine, error) {
+func DatamapFromDB(name string, db *sql.DB) ([]DatamapLine, error) {
var out []DatamapLine
@@ -185,7 +185,7 @@ func DMLFromDB(name string, db *sql.DB) ([]DatamapLine, error) {
// from the populated spreadsheet file file.
func ExtractDBDM(name string, file string, db *sql.DB) (ExtractedData, error) {
xdata := ReadXLSX(file)
- ddata, err := DMLFromDB(name, db) // this will need to return a []DatamapLine
+ ddata, err := DatamapFromDB(name, db) // this will need to return a []DatamapLine
if err != nil {
return nil, err
@@ -147,9 +147,9 @@ func ReadXLSX(ssheet string) FileData {
return outer
}
-// DMLFromDB fetches a slice of DatamapLine from the database given
+// DatamapFromDB fetches a slice of DatamapLine from the database given
// the name of a datamap.